<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Skryté skratky</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Ak týmto skratkám nastavíte vlastnú akciu v Nastavenia → Klávesové skratky, použujú sa vaše nastavenia.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Skratka</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Činnosť</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Zavrieť okno/Ukončiť režim celej obrazovky</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Šípka vpravo</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Ďalší obrázok</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Medzerník</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Posledný obrázok</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Šípka vľavo</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Predchádzajúci obrázok</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Domov</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Prvý obrázok</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Spustiť v režime celej obrazovky (vhodné pre správcov okien s dlaždicami)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="102"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Odfotiť obrazovku (zastaralá funkcia, použite prosím aplikáciu screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>DIR</source>
        <translation>PRIEČINOK</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Odfotiť obrazovku a uložiť do priečinka bez zobrazenia používateľského rozhrania (zastaralá funkcia, použite prosím aplikáciu screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="117"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[SÚBOR1, SÚBOR2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>Odpoveď: neznáma chyba</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>Odpoveď: neznáma chyba</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>About</source>
        <translation>O aplikácií</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>A simple and fast image viewer</source>
        <translation>Jednoduchý a rýchly prehliadač obrázkov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>2013-2021</source>
        <translation>2013-2021</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>LXQt Project</source>
        <translation>Projekt LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Development: </source>
        <translation>Vývoj: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Author: </source>
        <translation>Autor: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Open File</source>
        <translation>Otvoriť súbor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>Image files (%1)</source>
        <translation>Obrázkové súbory (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>Open directory</source>
        <translation>Otvoriť priečinok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Save File</source>
        <translation>Uložiť súbor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Načítam...) - Prehliadač obrázkov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="853"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Načítanie neúspešné) - Prehliadač obrázkov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="859"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Prehliadač obrázkov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Prehliadač obrázkov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1302"/>
        <source>Thumbnails</source>
        <translation>Náhľady</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>EXIF Data</source>
        <translation>Údaje EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Vymazať históriu</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Klávesovú skratku odstránite stlačením Ctrl
v režime úpravy.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="213"/>
        <source>Bottom</source>
        <translation>Na spodku</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="214"/>
        <source>Top</source>
        <translation>Na vrchu</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="341"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pozor: Nejednoznačná skratka!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="358"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nejednoznačná skratka nebola prijatá.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Súbor nie je možné uložiť v tomto formáte!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Veľkosť:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Cesta:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="50"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="51"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="134"/>
        <source>Start</source>
        <translation>Spustiť</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Stop</source>
        <translation>Zastaviť</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Close</source>
        <translation>Zavrieť</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="147"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Prehliadač obrázkov</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>Nedávno otvo&amp;rené súbory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>&amp;About</source>
        <translation>O &amp;aplikácií</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Annotations Toolbar</source>
        <translation>Nástroje na kreslenie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Otvoriť apli&amp;káciou...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Sorting</source>
        <translation>Usporiadať</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Skryté &amp;Skratky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Open…</source>
        <translation>&amp;Otvoriť…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Reload File</source>
        <translation>Zno&amp;va načítať</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>&amp;Save</source>
        <translation>&amp;Uložiť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Save &amp;As</source>
        <translation>Uložiť &amp;ako</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavrieť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;In</source>
        <translation>Pr&amp;iblížiť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Oddialiť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Skopírovať do s&amp;chránky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Next File</source>
        <translation>Ďalší súbor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Previous File</source>
        <translation>Predošlý súbor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Original Size</source>
        <translation>Pôvodná veľkosť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Fit</source>
        <translation>&amp;Prispôsobiť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Otočiť vp&amp;ravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Otočiť &amp;vľavo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>P&amp;references</source>
        <translation>Nas&amp;tavenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>&amp;Print</source>
        <translation>&amp;Tlač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>First File</source>
        <translation>Prvý súbor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="437"/>
        <source>Last File</source>
        <translation>Posledný súbor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nové okno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Prevrátiť &amp;horizontálne</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>Capture Screenshot</source>
        <translation>Odfotiť obrazovku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>F&amp;ull Screen</source>
        <translation>C&amp;elá obrazovka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>Flip &amp;Vertically</source>
        <translation>Prevrátiť &amp;vertikálne</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Prilepiť zo schránky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Prezentácia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="518"/>
        <source>&amp;Delete</source>
        <translation>O&amp;dstrániť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <source>Show Thumbnails</source>
        <translation>Zobraziť náhľady</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>File Properties</source>
        <translation>Vlastnosti súboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Open &amp;Directory</source>
        <translation>Otvoriť pri&amp;ečinok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Upload</source>
        <translation>Odoslať na internet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="561"/>
        <source>Upload the image</source>
        <translation>Odoslať obrázok na internet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Show EXIF Data</source>
        <translation>Zobraziť údaje EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>No Tool</source>
        <translation>Žiadny nástroj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Deselect all drawing tools</source>
        <translation>Zrušiť výber nástrojov na kreslenie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>Draw Arrow</source>
        <translation>Nakresliť šípku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="602"/>
        <source>Draw an arrow</source>
        <translation>Nakresliť šípku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="614"/>
        <source>Draw Rectangle</source>
        <translation>Nakresliť obdĺžnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Draw a hollow rectangle</source>
        <translation>Nakresliť prázdny obdĺžnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="629"/>
        <source>Draw Circle</source>
        <translation>Nakresliť kruh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Draw a hollow circle</source>
        <translation>Nakresliť prázdny kruh</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="644"/>
        <source>Draw Number</source>
        <translation>Opečiatkovať číslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Draw incrementing numbers</source>
        <translation>Opečiatkovať po sebe idúce čísla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Menubar</source>
        <translation>Ponuka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <source>&amp;Main Toolbar</source>
        <translation>Hlavný pa&amp;nel nástrojov</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Main Toolbar</source>
        <translation>Hlavná ponuka nástrojov</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Lišta nástrojov na kreslenie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="691"/>
        <location filename="../mainwindow.ui" line="694"/>
        <source>Show Outline</source>
        <translation>Zobraziť obrys</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="705"/>
        <source>Copy Pa&amp;th</source>
        <translation>Kopírovať &amp;cestu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy path</source>
        <translation>Kopírovať cestu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="716"/>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Resize</source>
        <translation>Zmeniť veľkosť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="739"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Podľa názvu súboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <source>By File Name</source>
        <translation>Podľa názvu súboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>By &amp;Modification Time</source>
        <translation>Podľa času poslednej z&amp;meny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>By Modification Time</source>
        <translation>Podľa času poslednej zmeny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>By C&amp;reation Time</source>
        <translation>Podľa času vy&amp;tvorenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>By Creation Time</source>
        <translation>Podľa času vytvorenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="772"/>
        <source>By File &amp;Size</source>
        <translation>Podľa veľko&amp;sti súboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>By File Size</source>
        <translation>Podľa veľkosti súboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="783"/>
        <source>By File &amp;Type</source>
        <translation>Podľa &amp;typu súboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>By File Type</source>
        <translation>Podľa typu súboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Súbor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Prejsť na</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Zobraziť</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>&amp;Edit</source>
        <translation>Úp&amp;ravy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Toolbar</source>
        <translation>Nástroje</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Vzhľad ikon:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Maximálna veľkosť súboru pre vytvorenie náhľadu:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Farba pozadia v režime okna:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Farba pozadia v režime celej obrazovky:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Maximálny počet nedávnych súborov:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Čas jednej snímky pri prezentácií (s):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Show image outline by default</source>
        <translation>Vždy zobraziť obrys obrázka</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Vždy zobraziť nástroje na kreslenie</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Fit images when navigating</source>
        <translation>Prispôsobiť veľkosť pri prepínaní obrázvko</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Rozmery náhľadu:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Vymazané súbory presunúť do koša (bez opýtania)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Vždy zobraziť náhľady</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Automaticky zobraziť podrobnosti o súbore</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Automaticky zobraziť ponuku</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Automaticky zobraziť panel nástrojov</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Obrázok</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Smooth images on zooming</source>
        <translation>Zobraziť plynulé priblíženie</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="264"/>
        <source>Shortcuts</source>
        <translation>Klávesové skratky</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="283"/>
        <source>Action</source>
        <translation>Činnosť</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="288"/>
        <source>Shortcut</source>
        <translation>Skratka</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="296"/>
        <source>Default</source>
        <translation>Predvolené</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Zmeniť veľkosť obrázka</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Šírka</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Súčasná veľkosť:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Nová veľkosť:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Zachovať pomer strán</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Snímka obrazovky</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Odfotiť obrazovku</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Oblasť</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Iba toto okno</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Zachytiť oblasť obrazovky</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Odfotiť aj kurzor myši</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Počkať:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Odfotiť názov a rám okna</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Nahrať na internet</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
</context>
</TS>
